Change Log
==========

..
   All enhancements and patches to theming will be documented
   in this file.  It adheres to the structure of http://keepachangelog.com/ ,
   but in reStructuredText instead of Markdown (for ease of incorporation into
   Sphinx documentation and the PyPI description).

   This project adheres to Semantic Versioning (http://semver.org/).

..


[0.1.0] - 2016-10-13
--------------------

* First release on PyPI.
* Models and Django admin integration
